/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { CommonModule } from "@angular/common";
import { Component } from "@angular/core";
import { FormControl, ReactiveFormsModule } from "@angular/forms";
import { RouterModule } from "@angular/router";
import { ApiService } from "../../api.service";
import { ConsentComponent } from "../../consent/consent.component";
import { ErrorComponent } from "../../error/error.component";
import { CheckboxComponent } from "../../inputs/checkbox/checkbox.component";
import { MultiLineComponent }
  from "../../inputs/multi-line/multi-line.component";
import { SelectMenuComponent }
  from "../../inputs/select-menu/select-menu.component";
import { SingleLineComponent }
  from "../../inputs/single-line/single-line.component";
import { SuccessComponent } from "../../success/success.component";
import { UserinfoComponent } from "../../userinfo/userinfo.component";
import type { Platform } from "@repo/types/prod/unions/platform";

@Component({
  imports: [
    RouterModule,
    CommonModule,
    ConsentComponent,
    UserinfoComponent,
    ErrorComponent,
    ReactiveFormsModule,
    CheckboxComponent,
    SingleLineComponent,
    SelectMenuComponent,
    MultiLineComponent,
    SuccessComponent,
  ],
  selector:    "staff-form",
  styleUrl:    "./staff.component.css",
  templateUrl: "./staff.component.html",
})
export class StaffComponent {
  public loading = false;
  public error = "";
  public success = false;

  public firstName = new FormControl("");
  public lastName = new FormControl("");
  public email = new FormControl("");
  public company = new FormControl("");

  public understandVolunteer = new FormControl(false);
  public platform = new FormControl<Platform>("Forum");
  public platformUsername = new FormControl("");
  public whyJoin = new FormControl("");
  public currentBehaviour = new FormControl("");
  public priorExperience = new FormControl("");
  public internalConflict = new FormControl("");
  public handlingTrauma = new FormControl("");
  public difficultSituation = new FormControl("");
  public leadershipSituation = new FormControl("");

  public consent = new FormControl(false);

  public constructor(private readonly apiService: ApiService) {}

  // eslint-disable-next-line complexity -- stfu
  public submit(event: MouseEvent): void {
    this.error = "";
    const { form } = event.target as HTMLButtonElement;
    const valid = form?.reportValidity();
    if (valid !== true) {
      return;
    }
    this.loading = true;

    this.apiService.
      submitStaff({
        consent:             this.consent.value ?? false,
        currentBehaviour:    this.currentBehaviour.value ?? undefined,
        difficultSituation:  this.difficultSituation.value ?? undefined,
        email:               this.email.value ?? undefined,
        firstName:           this.firstName.value ?? undefined,
        handlingTrauma:      this.handlingTrauma.value ?? undefined,
        internalConflict:    this.internalConflict.value ?? undefined,
        lastName:            this.lastName.value ?? undefined,
        leadershipSituation: this.leadershipSituation.value ?? undefined,
        platform:            this.platform.value ?? undefined,
        platformUsername:    this.platformUsername.value ?? undefined,
        priorExperience:     this.priorExperience.value ?? undefined,
        understandVolunteer: this.understandVolunteer.value ?? false,
        whyJoin:             this.whyJoin.value ?? undefined,
      }).
      then((response) => {
        if ("error" in response) {
          this.error = response.error;
          this.loading = false;
        } else {
          this.error = "";
          this.success = true;
        }
      }).
      catch(() => {
        this.error = "An error occurred while submitting the form.";
        this.loading = false;
      });
  }
}
