/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
import { listHandler } from "../handlers/list/generateHandlers.js";
import type { DatabasePath } from "../interfaces/databasePath.js";
import type { WrappedRoute } from "../interfaces/wrappedRoute.js";

/**
 * Mounts all of the routes to `/list/{type}` the various form submissions.
 * @param database - The Prisma client.
 * @returns A Fastify plugin.
 */
export const listRoutes: WrappedRoute = (database) => {
  return async(fastify) => {
    const routes: Array<DatabasePath> = [
      "appeals",
      "commissions",
      "contacts",
      "events",
      "meetings",
      "mentorships",
      "staff",
      "testimonials",
    ];
    for (const route of routes) {
      fastify.get(`/list/${route}`, async(_request, response) => {
        await listHandler(database, route, response);
      });
    }
  };
};
