/**
 * @copyright nhcarrigan
 * @license Naomi's Public License
 * @author Naomi Carrigan
 */
/* eslint-disable @typescript-eslint/naming-convention -- We're dealing with Fastify's conventions here. */
import { submitAppealHandler } from "../handlers/submit/appealHandler.js";
import { submitCommissionHandler }
  from "../handlers/submit/commissionHandler.js";
import { submitContactHandler } from "../handlers/submit/contactHandler.js";
import { submitEventHandler } from "../handlers/submit/eventHandler.js";
import { submitMeetingHandler } from "../handlers/submit/meetingHandler.js";
import { submitMentorshipHandler }
  from "../handlers/submit/mentorshipHandler.js";
import { submitStaffHandler } from "../handlers/submit/staffHandler.js";
import { submitTestimonialHandler }
  from "../handlers/submit/testimonialHandler.js";
import type { WrappedRoute } from "../interfaces/wrappedRoute.js";
import type {
  Appeal,
  Commission,
  Contact,
  Event,
  Meeting,
  Mentorship,
  Staff,
  ErrorResponse,
  SuccessResponse,
  Testimonial,
} from "@repo/types";

/**
 * Handles all of the routes to `/submit/` the various forms.
 * @param database - The Prisma client.
 * @returns A Fastify plugin.
 */
// eslint-disable-next-line max-lines-per-function -- Prisma typings don't allow us to mount these dynamically...
export const submitRoutes: WrappedRoute = (database) => {
  return async(fastify) => {
    fastify.post<{ Body: Appeal; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/appeals",
      async(request, response) => {
        await submitAppealHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Commission; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/commissions",
      async(request, response) => {
        await submitCommissionHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Contact; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/contacts",
      async(request, response) => {
        await submitContactHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Event; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/events",
      async(request, response) => {
        await submitEventHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Meeting; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/meetings",
      async(request, response) => {
        await submitMeetingHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Mentorship; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/mentorships",
      async(request, response) => {
        await submitMentorshipHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Staff; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/staff",
      async(request, response) => {
        await submitStaffHandler(database, request, response);
      },
    );

    fastify.post<{ Body: Testimonial; Reply: SuccessResponse | ErrorResponse }>(
      "/submit/testimonials",
      async(request, response) => {
        await submitTestimonialHandler(database, request, response);
      },
    );
  };
};
